@@ -217,8 +217,8 @@ function(y,
                  x <- rbind(x,aa)
              }
              out <- NULL
-             library(nlme)
-			 library(MASS)
+             #library(nlme)
+	#		 library(MASS)
              fit0 <- glmmPQL(ywork2~x-1+offset(roffset),random = ~ 1 | id,family=binomial(logit), verbose = FALSE) 
 
              beta <- as.vector(fit0$coeff$fixed[2:nitem])
