@@ -234,54 +234,55 @@ c++++ data
       integer nrec,p
       integer censor
       integer typed(nrec)
-      real*8 ymat(nrec,2)
-      real*8 z(nrec,p)
+      double precision ymat(nrec,2)
+      double precision z(nrec,p)
 
 c++++ prediction
       integer ngrid,npred
-      real*8 grid(ngrid)
-      real*8 zpred(npred,p)
+      double precision grid(ngrid)
+      double precision zpred(npred,p)
 
 c++++ prior
       integer nu  
-      real*8 a0b0(2)
-      real*8 tau1
-      real*8 taus1,taus2
-      real*8 m0(p)
-      real*8 sbeta0i(p,p)
-      real*8 psiinv(p,p)
+      double precision a0b0(2)
+      double precision tau1
+      double precision taus1,taus2
+      double precision m0(p)
+      double precision sbeta0i(p,p)
+      double precision psiinv(p,p)
 
 c++++ current value
       integer ncluster
       integer ss(nrec)
-      real*8 alpha
-      real*8 betaclus(nrec+100,p)
-      real*8 sigmaclus(nrec+100)
-      real*8 mub(p)
-      real*8 sb(p,p)
-      real*8 tau2
-      real*8 y(nrec)
+      double precision alpha
+      double precision betaclus(nrec+100,p)
+      double precision sigmaclus(nrec+100)
+      double precision mub(p)
+      double precision sb(p,p)
+      double precision tau2
+      double precision y(nrec)
 
 c++++ output
-      real*8 cpo(nrec,2)
-      real*8 thetasave(nsave,p+p*(p+1)/2+3)
-      real*8 randsave(nsave,nrec*(p+1))
-      real*8 survsave(nsave,npred*ngrid)
-      real*8 denspm(npred,ngrid)
-      real*8 denspl(npred,ngrid)
-      real*8 densph(npred,ngrid)
-      real*8 hazpm(npred,ngrid)
-      real*8 hazpl(npred,ngrid)
-      real*8 hazph(npred,ngrid)
-      real*8 meanfpm(npred)
-      real*8 meanfpl(npred)
-      real*8 meanfph(npred)
-      real*8 survpm(npred,ngrid)
-      real*8 survpl(npred,ngrid)
-      real*8 survph(npred,ngrid)
+      integer nsave
+      double precision cpo(nrec,2)
+      double precision thetasave(nsave,p+p*(p+1)/2+3)
+      double precision randsave(nsave,nrec*(p+1))
+      double precision survsave(nsave,npred*ngrid)
+      double precision denspm(npred,ngrid)
+      double precision denspl(npred,ngrid)
+      double precision densph(npred,ngrid)
+      double precision hazpm(npred,ngrid)
+      double precision hazpl(npred,ngrid)
+      double precision hazph(npred,ngrid)
+      double precision meanfpm(npred)
+      double precision meanfpl(npred)
+      double precision meanfph(npred)
+      double precision survpm(npred,ngrid)
+      double precision survpl(npred,ngrid)
+      double precision survph(npred,ngrid)
 
 c++++ mcmc
-      integer mcmc(3),nburn,nskip,nsave,ndisplay
+      integer mcmc(3),nburn,nskip,ndisplay
   
 c++++ seeds
       integer seed1,seed2,seed(2)
@@ -290,24 +291,24 @@ c++++ external working space
       integer cstrt(nrec,nrec)
       integer ccluster(nrec)
       integer iflagp(p)
-      real*8 betam(p)
-      real*8 betawork(p)
-      real*8 prob(nrec+100)
-      real*8 workmh1(p*(p+1)/2)
-      real*8 workmh2(p*(p+1)/2)
-      real*8 workv1(p) 
-      real*8 xtx(p,p)
-      real*8 xtx2(p,p)
-      real*8 xty(p)
-      real*8 xty2(p)
+      double precision betam(p)
+      double precision betawork(p)
+      double precision prob(nrec+100)
+      double precision workmh1(p*(p+1)/2)
+      double precision workmh2(p*(p+1)/2)
+      double precision workv1(p) 
+      double precision xtx(p,p)
+      double precision xtx2(p,p)
+      double precision xty(p)
+      double precision xty2(p)
 
-      real*8 fs(ngrid) 
-      real*8 fm(npred) 
+      double precision fs(ngrid) 
+      double precision fm(npred) 
  
-      real*8 worksam(nsave) 
+      double precision worksam(nsave) 
 
-      real*8 workcpo(nrec)
-      real*8 workcpo2(nrec)
+      double precision workcpo(nrec)
+      double precision workcpo2(nrec)
       
 c++++ internal working space
       integer count
@@ -322,30 +323,30 @@ c++++ internal working space
       integer since
       integer skipcount
       integer sprint
-      real*8 cdflnorm
-      real*8 cdfnorm
-      real*8 dnrm
-      real*8 dlnrm
-      real*8 rgamma
-      real*8 liminf
-      real*8 limsup
-      real*8 muwork
-      real*8 rtnorm
-      real*8 sigmawork
-      real*8 tmp1,tmp2,tmp3,tmp4
-      real*8 yc
+      double precision cdflnorm
+      double precision cdfnorm
+      double precision dnrm
+      double precision dlnrm
+      double precision rgamma
+      double precision liminf
+      double precision limsup
+      double precision muwork
+      double precision rtnorm
+      double precision sigmawork
+      double precision tmp1,tmp2,tmp3,tmp4
+      double precision yc
 
-      real*8 cpotest
-      real*8 cpotest2
+      double precision cpotest
+      double precision cpotest2
       
       logical ainf,asup
    
 c++++ DP (functional parameter)
-      real*8 eps,rbeta,weight
+      double precision eps,rbeta,weight
       parameter(eps=0.01)
 
 c++++ CPU time
-      real*8 sec00,sec0,sec1,sec
+      double precision sec00,sec0,sec1,sec
 
 c++++ opening files
 
@@ -1048,11 +1049,11 @@ c+++++++++++++ Partially sampling the DP (and CPO).
                      ii=ii+1
                      survsave(isave,ii)=survpl(i,j)
                   end do
-                  write(1) (denspl(i,j),j=1,ngrid)
-                  write(3) (survpl(i,j),j=1,ngrid)
-                  write(4) (hazpl(i,j),j=1,ngrid)
+c                 write(1) (denspl(i,j),j=1,ngrid)
+c                  write(3) (survpl(i,j),j=1,ngrid)
+c                  write(4) (hazpl(i,j),j=1,ngrid)
                end do 
-               write(2) (fm(i),i=1,npred)
+c               write(2) (fm(i),i=1,npred)
 
 c+++++++++++++ lpml
 
@@ -1131,21 +1132,21 @@ c=======================================================================
 c+++++External parameters
       integer tint
       integer nsave,npred,ngrid 
-      real*8 alpha
+      double precision alpha
 
 c+++++External working
-      real*8 fs(ngrid)
-      real*8 workv1(nsave)
+      double precision fs(ngrid)
+      double precision workv1(nsave)
 
 c+++++Output      
-      real*8 llower(npred,ngrid)
-      real*8 lupper(npred,ngrid)
+      double precision llower(npred,ngrid)
+      double precision lupper(npred,ngrid)
 
 c+++++Internal parameters
       integer maxnsave,maxngrid
       parameter(maxnsave=30000,maxngrid=500)
-      real*8 aupp(2),alow(2)
-      real*8 workm(maxnsave,maxngrid)
+      double precision aupp(2),alow(2)
+      double precision workm(maxnsave,maxngrid)
 
 c+++++Internal working
       integer i,ii,j,l   
@@ -1220,21 +1221,21 @@ c=======================================================================
 c+++++External parameters
       integer tint
       integer nsave,npred,ngrid 
-      real*8 alpha
+      double precision alpha
 
 c+++++External working
-      real*8 fs(ngrid)
-      real*8 workv1(nsave)
+      double precision fs(ngrid)
+      double precision workv1(nsave)
 
 c+++++Output      
-      real*8 llower(npred,ngrid)
-      real*8 lupper(npred,ngrid)
+      double precision llower(npred,ngrid)
+      double precision lupper(npred,ngrid)
 
 c+++++Internal parameters
       integer maxnsave,maxngrid
       parameter(maxnsave=30000,maxngrid=300)
-      real*8 aupp(2),alow(2)
-      real*8 workm(maxnsave,maxngrid)
+      double precision aupp(2),alow(2)
+      double precision workm(maxnsave,maxngrid)
 
 c+++++Internal working
       integer i,ii,j,l   
