@@ -323,45 +323,27 @@ c++++ external working space - vector and matrices
  
 c++++ internal working space
       integer accept,acceptt
-      integer i,ii,i1,j,jj,j1,k1,ll,l1,l2,mm
+      integer i,ii,i1,j,jj,j1,k1,ll,mm
       integer d1,d2
       integer dispcount,iscan,isave
       integer ntot,n1,n2
       integer nscan,skipcount
       integer sprint
-      double precision alnorm
-      double precision alphac
-      double precision dnrm
-      double precision dinvnorm
-      double precision liminf
-      double precision limsup
       double precision loglikn,logliko
-      double precision logpriorn,logprioro
-      double precision logcgkn,logcgko
-      double precision luni,lratio
-      double precision qqnum
-      double precision rbeta
+      double precision logpriorn
       double precision rgamma
-      double precision rtnorm
-      double precision rnorm
       real runif
-      double precision sigma2c
       double precision tmp1,tmp2,tmp3
       double precision uni
-      double precision ya
-      double precision yc
-  
-      logical ainf
-      logical asup
   
 c++++ CPU time
       double precision sec00,sec0,sec1,sec
 
 c++++ Working space slice sampling
       integer evali
-      double precision rexpo,re,uwork
+      double precision re,uwork
       double precision logy,xx0,xx1,llim,rlim
-      double precision grlim,gllim,gxx0,gxx1
+      double precision grlim,gllim,gxx1
 
 c++++ initializing variables
 
